@@ -1,6 +1,6 @@
 import asyncio
 import os
-from typing import Any, Literal, Optional, Union
+from typing import Any, Callable, Dict, List, Literal, Optional, Union
 
 from ..jsonrpc2.protocol import rpc_method
 from ..jsonrpc2.server import JsonRPCServer, JsonRpcServerMode, TcpParams
@@ -8,6 +8,8 @@ from ..utils import async_tools
 from ..utils.async_tools import run_coroutine_from_thread
 from ..utils.logging import LoggingDescriptor
 from .dap_types import (
+    AttachRequestArguments,
+    Capabilities,
     ConfigurationDoneArguments,
     ContinueArguments,
     ContinueResponseBody,
@@ -16,9 +18,11 @@ from .dap_types import (
     EvaluateArguments,
     EvaluateResponseBody,
     Event,
+    ExceptionBreakpointsFilter,
     ExitedEvent,
     ExitedEventBody,
     InitializedEvent,
+    InitializeRequestArguments,
     NextArguments,
     PauseArguments,
     ScopesArguments,
@@ -40,7 +44,7 @@ from .dap_types import (
     VariablesArguments,
     VariablesResponseBody,
 )
-from .debugger import Debugger
+from .debugger import Debugger, PathMapping
 from .protocol import DebugAdapterProtocol
 
 TCP_DEFAULT_PORT = 6612
@@ -52,12 +56,14 @@ class DebugAdapterServerProtocol(DebugAdapterProtocol):
     def __init__(self) -> None:
         super().__init__()
 
-        self._initialized = False
         self._connected_event = async_tools.Event()
         self._disconnected_event = async_tools.Event()
         self._connected = False
         self._sigint_signaled = False
 
+        self._initialized = False
+        self._initialized_event = async_tools.Event()
+
         self._exited_lock = async_tools.Lock()
         self._exited = False
 
@@ -66,6 +72,7 @@ class DebugAdapterServerProtocol(DebugAdapterProtocol):
 
         self._received_configuration_done_event = async_tools.Event()
         self._received_configuration_done = False
+        self.received_configuration_done_callback: Optional[Callable[[], None]] = None
 
         Debugger.instance().send_event.add(self.on_debugger_send_event)
 
@@ -111,15 +118,90 @@ class DebugAdapterServerProtocol(DebugAdapterProtocol):
 
         return self._connected
 
+    @_logger.call
+    async def wait_for_initialized(self, timeout: float = 60) -> bool:
+        await asyncio.wait_for(self._initialized_event.wait(), timeout)
+
+        return self._initialized
+
     @_logger.call
     async def wait_for_disconnected(self, timeout: float = 60) -> bool:
         await asyncio.wait_for(self._disconnected_event.wait(), timeout)
 
         return self._connected
 
+    @rpc_method(name="initialize", param_type=InitializeRequestArguments)
+    async def _initialize(self, arguments: InitializeRequestArguments, *args: Any, **kwargs: Any) -> Capabilities:
+        self._initialized = True
+
+        if self.loop is not None:
+            self.loop.call_soon(self.initialized)
+
+        return Capabilities(
+            supports_configuration_done_request=True,
+            supports_conditional_breakpoints=True,
+            supports_hit_conditional_breakpoints=True,
+            support_terminate_debuggee=True,
+            # support_suspend_debuggee=True,
+            supports_evaluate_for_hovers=True,
+            supports_terminate_request=True,
+            supports_log_points=True,
+            supports_set_expression=True,
+            supports_set_variable=True,
+            supports_value_formatting_options=True,
+            exception_breakpoint_filters=[
+                ExceptionBreakpointsFilter(
+                    filter="failed_keyword",
+                    label="Failed Keywords",
+                    description="Breaks on failed keywords",
+                    default=False,
+                ),
+                ExceptionBreakpointsFilter(
+                    filter="uncaught_failed_keyword",
+                    label="Uncaught Failed Keywords",
+                    description="Breaks on uncaught failed keywords",
+                    default=True,
+                ),
+                ExceptionBreakpointsFilter(
+                    filter="failed_test",
+                    label="Failed Test",
+                    description="Breaks on failed tests",
+                    default=False,
+                ),
+                ExceptionBreakpointsFilter(
+                    filter="failed_suite",
+                    label="Failed Suite",
+                    description="Breaks on failed suite",
+                    default=False,
+                ),
+            ],
+            supports_exception_options=True,
+            supports_exception_filter_options=True,
+        )
+
+    @rpc_method(name="attach", param_type=AttachRequestArguments)
+    async def _attach(
+        self,
+        arguments: AttachRequestArguments,
+        request: Optional[str] = None,
+        type: Optional[str] = None,
+        name: Optional[str] = None,
+        restart: Optional[bool] = None,
+        pathMappings: Optional[List[Dict[str, str]]] = None,  # noqa: N803
+        *args: Any,
+        **kwargs: Any,
+    ) -> None:
+        if pathMappings:
+            Debugger.instance().path_mappings = [
+                PathMapping(local_root=v.get("localRoot", None), remote_root=v.get("remoteRoot", None))
+                for v in pathMappings
+            ]
+        Debugger.instance().attached = True
+
     @_logger.call
-    async def initialized(self) -> None:
-        await self.send_event_async(InitializedEvent())
+    def initialized(self) -> None:
+        self.send_event(InitializedEvent())
+        self._initialized_event.set()
 
     @_logger.call
     async def exit(self, exit_code: int) -> None:
@@ -137,24 +219,32 @@ class DebugAdapterServerProtocol(DebugAdapterProtocol):
     async def _terminate(self, arguments: Optional[TerminateArguments] = None, *args: Any, **kwargs: Any) -> None:
         import signal
 
-        Debugger.instance().terminate()
-
         if not self._sigint_signaled:
             self._logger.info("Send SIGINT to process")
             signal.raise_signal(signal.SIGINT)
             self._sigint_signaled = True
+            # Debugger.instance().continue_all()
         else:
+            await self.send_event_async(Event("terminateRequested"))
+
+            Debugger.instance().terminate()
+
             self._logger.info("Send SIGTERM to process")
             signal.raise_signal(signal.SIGTERM)
 
     @rpc_method(name="disconnect", param_type=DisconnectArguments)
     async def _disconnect(self, arguments: Optional[DisconnectArguments] = None, *args: Any, **kwargs: Any) -> None:
+
         if (
-            not (await self.exited)
-            or not (await self.terminated)
-            and (arguments is None or arguments.terminate_debuggee is None or arguments.terminate_debuggee)
+            (not (await self.exited) or not (await self.terminated))
+            and arguments is not None
+            and arguments.terminate_debuggee
         ):
             os._exit(-1)
+        else:
+            await self.send_event_async(Event("disconnectRequested"))
+            Debugger.instance().attached = False
+            Debugger.instance().continue_all(False)
 
     @rpc_method(name="setBreakpoints", param_type=SetBreakpointsArguments)
     async def _set_breakpoints(
@@ -174,6 +264,10 @@ class DebugAdapterServerProtocol(DebugAdapterProtocol):
         self._received_configuration_done = True
         self._received_configuration_done_event.set()
 
+        if self.received_configuration_done_callback is not None:
+
+            self.received_configuration_done_callback()
+
     @_logger.call
     async def wait_for_configuration_done(self, timeout: float = 5) -> bool:
         await asyncio.wait_for(self._received_configuration_done_event.wait(), timeout)
